@@ -26,6 +26,7 @@ import java.net.URL;
  * @author <a href="mailto:kai.ahrens@open-xchange.com">Kai Ahrens</a>
  */
 public class Config {
+
     /**
      * the directory, containing the ./program directory of the underlying readerengine
      */
@@ -42,26 +43,65 @@ public class Config {
     public String ENGINE_SCRATCHDIR = "/var/spool/open-xchange/documentconverter/readerengine.scratch";
 
     /**
-     * Base URL to be used for remote conversions;
-     * if left empty, the current backend will handle the conversions
+     * a temp. directory, containing files that could not be loaded due to an error condition or due to a timeout
+     */
+    public String ENGINE_ERRORDIR = "/var/spool/open-xchange/documentconverter/readerengine.error";
+
+    /**
+     * external URL blacklist file
+     */
+    public String ENGINE_URL_BLACKLIST_FILE = "/opt/open-xchange/etc/readerengine.blacklist";
+
+    /**
+     * external URL whitelist file
+     */
+    public String ENGINE_URL_WHITELIST_FILE = "/opt/open-xchange/etc/readerengine.whitelist";
+
+    /**
+     * external URL maximum link count
+     */
+    public int ENGINE_URL_LINK_LIMIT = 120;
+
+    /**
+     * proxy server for external readerengine URLs
+     */
+    public String ENGINE_URL_LINK_PROXY = null;
+
+    /**
+     * Base URL to be used for remote conversions; if left empty, the current backend will handle the conversions
      */
     public URL ENGINE_REMOTE_BASEURL = null;
 
     /**
-     * Cache URL(s) to be used for remote conversions;
-     * the local backend will handle caching in every case, but a cache
-     * speedup can be achieved by adding additional cache servers
+     * Cache URL(s) to be used for remote conversions; the local backend will handle caching in every case, but a cache speedup can be
+     * achieved by adding additional cache servers
      */
     public URL[] ENGINE_REMOTE_CACHEURLS = null;
 
+    /**
+     * Sharepoint URL to be used for MSO to PDF conversions; if left empty, the corresponding MSO2PDFConverter jobs will always return
+     * false; a fallback behavior/call should be implemented in every case
+     */
+    public URL ENGINE_REMOTE_SHAREPOINTURL = null;
+
+    /**
+     * The login user name to be used for calls to the SharePoint service
+     */
+    public String ENGINE_REMOTE_SHAREPOINTUSERNAME = null;
+
+    /**
+     * The login password to be used for calls to the SharePoint service
+     */
+    public String ENGINE_REMOTE_SHAREPOINTPASSWORD = null;
+
     /**
      * the location of the log
      */
     public String ENGINE_LOGFILE = "/var/log/open-xchange/readerengine.log";
 
     /**
-     * determines the amount and detail of logging data;
-     * 3 = errors, 2 = errors and warnings, 1 = errors and warnings and infos, 0 = disabled
+     * determines the amount and detail of logging data; 3 = errors, 2 = errors and warnings, 1 = errors and warnings and infos, 0 =
+     * disabled
      */
     public int ENGINE_LOGLEVEL = 1;
 
@@ -81,8 +121,7 @@ public class Config {
     public long ENGINE_JOB_EXECUTION_TIMEOUT_MILLISECONDS = 60000;
 
     /**
-     * the maximum size in MegaBytes of virtual memory that a readerengine instance can allocate;
-     * -1 for no upper limit
+     * the maximum size in MegaBytes of virtual memory that a readerengine instance can allocate; -1 for no upper limit
      */
     public long ENGINE_MAX_VMEM_MB = 2048;
 
@@ -92,22 +131,20 @@ public class Config {
     public long ENGINE_MIN_FREE_VOLUMESIZE_MB = 1024;
 
     /**
-     * the maximum size in MegaBytes of all persistently cached converter job entries at runtime;
-     * the total cache size will also take into account the value for the minimum free volume size,
-     * so that at least this free volume size will not be occupied by the cache
-     * -1 for no upper limit
+     * the maximum size in MegaBytes of all persistently cached converter job entries at runtime; the total cache size will also take into
+     * account the value for the minimum free volume size, so that at least this free volume size will not be occupied by the cache -1 for
+     * no upper limit
      */
     public long ENGINE_MAX_CACHESIZE_MB = -1;
 
     /**
-     * the maximum count of converter jobs cached at runtime;
-     * -1 for no upper limit
+     * the maximum count of converter jobs cached at runtime; -1 for no upper limit
      */
     public long ENGINE_MAX_CACHEENTRIES = -1;
 
     /**
-     * the timeout in seconds, after which a cached job execution result is automatically removed from the cache
-     * 0 for disabling the timeout based removal
+     * the timeout in seconds, after which a cached job execution result is automatically removed from the cache 0 for disabling the timeout
+     * based removal
      */
     public long ENGINE_CACHEENTRY_TIMEOUT_SECONDS = 2592000;
 
@@ -117,7 +154,17 @@ public class Config {
     public boolean SERVLET_ENGINE_LOCAL_FILE_URLS = false;
 
     /**
-     * the log4j logger to be used for logging
+     * Internal flag to enable the debug mode
      */
-    public org.apache.commons.logging.Log logger = null;
+    public boolean ENGINE_DEBUG = false;
+
+    /**
+     * the logger to be used for logging
+     */
+    public org.slf4j.Logger logger = null;
+
+    /**
+     * the location of the performance directory
+     */
+    public String ENGINE_PERFORMANCEDIR = null;
 }
