@@ -13,7 +13,11 @@
 
 package com.openexchange.documentconverter;
 
-
 public enum Feature {
-    DOCUMENTCONVERTER
+    DOCUMENTCONVERTER,
+
+    SHAREPOINT_PDFCONVERSION, // you may pass a source mime type String parameter to the IManager.hasFeature method, in order to detect if
+                             // the SharePoint service is supported for this kind of source document
+
+    REMOTE_DOCUMENTCONVERTER
 }
