@@ -38,7 +38,7 @@ public interface IInstance {
      * @param maxVMemMB
      * @return true in case the IInstance was successfully launched
      */
-    public boolean launch(BackendType backendtype, String installDir, String userBaseDir, long maxVMemMB);
+    public boolean launch(BackendType backendtype, String installDir, String userBaseDir, long maxVMemMB, String blacklistFile, String whitelistFile, int urlLinkLimit, String urlLinkProxy);
 
     /**
      * synchronous shutdown of a launched IInstance
