@@ -44,7 +44,7 @@ public interface IManager {
      * @param feature the feature that is queried to be supported
      * @return true if the given feature is supported by this IManager instance
      */
-    boolean hasFeature(Feature feature);
+    boolean hasFeature(Feature feature, Object... params);
 
     /**
      * @return the successfully initialized JobProcessor or null in case of failure
@@ -56,6 +56,11 @@ public interface IManager {
      */
     ICache getCache();
 
+    /**
+     * @return the installation path of the underlying DocumentReaderEngine or null if the engine wasn't properly initialized
+     */
+    public String getEnginePath();
+
     /**
      * @param jobType the export format for the conversion
      * @param jobProperties contains additional properties to customize the job
@@ -63,30 +68,19 @@ public interface IManager {
      */
     public IJob createServerJob(String jobType, HashMap<String, Object> jobProperties, HashMap<String, Object> resultProperties);
 
-    /**
-     * @return the instance that offers a UNO interface to the underlying engine backend or null in case of a failure
-     */
-    public IInstance createServerInstance(BackendType backendType);
-
     /**
      * @param jobType The job type fiter to be executed.
      * @param jobProperties Input parameter, containing properties to customize the job (e.g. the InputFile)
      * @param resultProperties Output parameter,  containing additional conversion result properties like e.g. the PageCount of the conversion result.
      * @return The InputStream with the conversion result in case of success or null in case of a failure
      */
-    /**
-     * @param jobType
-     * @param jobProperties
-     * @param resultProperties
-     * @return The InputStream with the conversion result in case of success or null in case of a failure
-     */
     public InputStream convert(String jobType, HashMap<String, Object> jobProperties, HashMap<String, Object> resultProperties);
 
     /**
      * @param jobType The job type fiter to be executed.
      * @param documentInputStream The InputStream, containing the source document to be converted.
      * @param jobProperties Input parameter, containing properties to customize the job (e.g. the InputFile)
-     * @param resultProperties Output parameter,  containing additional conversion result properties like e.g. the PageCount of the conversion result.
+     * @param resultProperties Output parameter,  containing additional conversion result properties like e.g. the error code of the conversion result.
      * @return The job id string to be used in further getConversionPage/endPageConversion jobs or null in case of a failure
      */
     public String beginPageConversion(String jobType, HashMap<String, Object> jobProperties, HashMap<String, Object> resultProperties);
@@ -94,21 +88,18 @@ public interface IManager {
     /**
      * @param jobIdStr The job id gotten from a previous call to beginPageConversion
      * @param pageNumber The number of the page to be returned as input stream.
-     * @param pageProperties input/output parameter, containing additional properties to customize the job (input) and containing additional
-     *            conversion result properties like e.g. the mime type of the conversion result (output).
+     * @param jobProperties Input parameter, containing properties to further customize the job, can be empty in this case
+     * @param resultProperties Output parameter,  containing additional conversion result properties like e.g. the PageCount of the conversion result.
      * @return The stream the converted page can be read from or null in case of a failure
      */
-    public InputStream getConversionPage(String jobIdStr, int pageNumber, HashMap<String, Object> resultProperties);
+    public InputStream getConversionPage(String jobIdStr, int pageNumber, HashMap<String, Object> jobProperties, HashMap<String, Object> resultProperties);
 
     /**
      * @param jobIdStr The job id gotten from a previous call to beginPageConversion
+     * @param jobProperties Input parameter, containing properties to further customize the job, can be empty in this case
+     * @param resultProperties Output parameter, containing additional conversion result properties like e.g. the error code of the conversion result.
      */
-    public void endPageConversion(String jobIdStr);
-
-    /**
-     * @return the installation path of the underlying DocumentReaderEngine or null if the engine wasn't properly initialized
-     */
-    public String getEnginePath();
+    public void endPageConversion(String jobIdStr, HashMap<String, Object> jobProperties, HashMap<String, Object> resultProperties);
 
 
     /**
@@ -130,4 +121,9 @@ public interface IManager {
      * @param sourceFileName if source document file name is set then the temp file will be created with this file name within a new folder
      */
     public File createTempFile(String prefix, String sourceFileName);
+
+    /**
+     * @return
+     */
+    public Config getConverterConfig();
 }
